Package: GraphAT
Title: Graph Theoretic Association Tests
Version: 1.83.0
Date: 2012-04-27
Author: R. Balasubramanian, T. LaFramboise, D. Scholtens
Description: Functions and data used in Balasubramanian, et al. (2004)
Maintainer: Thomas LaFramboise <tlaframb@hsph.harvard.edu>
Depends: R (>= 2.10), graph, methods
Imports: graph, MCMCpack, methods, stats
License: LGPL
biocViews: Network, GraphAndNetwork
git_url: https://git.bioconductor.org/packages/GraphAT
git_branch: devel
git_last_commit: 581549b
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 21:23:34 UTC; biocbuild
